# frozen_string_literal: true

module Reports
  class RecurringLogics < ForemanMaintain::Report
    metadata do
      description 'Check remote execution usage'
    end

    def run
      self.data = {}

      cte = <<~CTE
        WITH bootc_hosts AS (
          SELECT hosts.id FROM hosts
          INNER JOIN katello_content_facets AS kcf ON hosts.id = kcf.host_id
          WHERE kcf.bootc_booted_digest IS NOT NULL
        )
      CTE

      sql = <<~SQL
        job_invocations AS ji
          INNER JOIN remote_execution_features AS ref ON ji.remote_execution_feature_id = ref.id
          INNER JOIN template_invocations AS ti ON ji.id = ti.job_invocation_id
          INNER JOIN bootc_hosts ON bootc_hosts.id = ti.host_id
          WHERE ref.label LIKE 'katello_package%'
             OR ref.label LIKE 'katello_errata%'
             OR ref.label LIKE 'katello_group%'
      SQL

      data['remote_execution_transient_package_actions_count'] = sql_count(sql, cte: cte)
    end
  end
end
